<template>
  <div class="map-container">
    <wrapper-title :title="'区域地图'"></wrapper-title>
    <div class="map-content">
      <div ref="map" class="map-style"></div>
    </div>
  </div>

</template>

<script>
import * as echarts from 'echarts';
import 'echarts-gl';
import mapData from '@/assets/map/zigong1.json';
import WrapperTitle from '../wrapper-title/index';

echarts.registerMap('zigong', mapData);
let mapChart = null;
let tempName = '';
let observer = null;
const mapConfig = {
  geo3D: {
    map: 'zigong',
    show: true,
    bottom: 0,
    left: 0,
    top: 0,
    right: 0,
    zlevel: 1,
    itemStyle: {
      color: "#4189f2", // 背景
      opacity: 1, //透明度
      borderWidth: 1, // 边框宽度
      borderColor: "#fff", // 边框颜色
      fontSize: 18, //
    },

    // 标签
    label: {
      show: true,
      color: "#fff", //地图初始化区域字体颜色
      fontSize: 18,
    },
    // 控制器
    viewControl: {
      beta: -30,
      alpha: 50,
      distance: 78,
      maxBeta: 180,
      panSensitivity: 0,
      zoomSensitivity: 1,
      rotateSensitivity: 0,
    },
    // 鼠标移入时样式
    emphasis: {
      itemStyle: {
        color: "#F63545",
      }
    },
    // regions: mapData.features.map((item) => {
    //   return {
    //     name: item.properties.name,
    //     itemStyle: {
    //       color: "#4189f2"
    //     }
    //   }
    // })
  },
  series: [
    {
      map: "zigong", //注册地图的名字
      type: "map3D",
      bottom: 0,
      left: 0,
      top: 0,
      right: 0,
      zlevel: 2,
      itemStyle: {
        color: "#4189f2", // 背景
        opacity: 0, //透明度
        borderWidth: 0, // 边框宽度
        borderColor: "#fff", // 边框颜色
        fontSize: 18, //
      },

      // 标签
      label: {
        show: false,
        color: "#fff", //地图初始化区域字体颜色
        fontSize: 18,
      },
      // 控制器
      viewControl: {
        beta: -30,
        alpha: 50,
        distance: 78,
        maxBeta: 180,
        panSensitivity: 0,
        zoomSensitivity: 1,
        rotateSensitivity: 0,
      },
      
      // 数据
      data: mapData.features.map((item) => {
        return {
          name: item.properties.name,
          itemStyle: {
            color: "#4189f2"
          }
        }
      }),

    },
    {
      type: 'lines3D',
      coordinateSystem: 'geo3D',
      zlevel: 15,

      effect: {
        show: true,
        period: 5,
        trailLength: 0.2,
        color: '#01AAED',
      },
      lineStyle: {
        width: 3,
        opacity: 0.6,
        color: '#FFB800'
      },
      data: [
        [
          [104.343914,29.470778],
          [104.766432,29.328016]
        ],
        [
          [104.603116,29.347364],
          [104.766432,29.328016]
        ],
        [
          [104.873139,29.30861],
          [104.766432,29.328016]
        ],
        [
          [105.058792,29.1521],
          [104.766432,29.328016]
        ],
        [
          [104.848535,29.410526],
          [104.766432,29.328016]
        ],
      ]
    }
  ]

};
export default {
  name: 'DataMap',
  data() {
    return {

    }
  },
  components: {
    WrapperTitle
  },
  methods: {
    filterData(name) {
      this.initConfig();
      let temp = mapConfig.geo3D.regions.find(item => item.name === name);

      // mapConfig.geo3D.regions.push({
      //   name: name,
      //   itemStyle: {
      //     color: '#F63545'
      //   }
      // });
      temp.itemStyle.color = '#F63545';
      mapChart.setOption(mapConfig, true);
      this.$emit('filterData', name);
    },
    initConfig() {
      // mapConfig.geo3D.regions = [];
      mapConfig.geo3D.regions.forEach(item => {
        item.itemStyle.color = '#4189f2';
      });
    },
    // 监听变化
    observe() {
      if (!observer) {
        observer = new ResizeObserver(entries => {
          this.handleResize();
        })
      }
      observer.observe(this.$refs.map);
    },
    // 窗口变换
    handleResize() {
      if (mapChart) {
        mapChart.resize();
      }
    }
  },
  mounted() {
    mapChart = echarts.init(this.$refs.map);
    mapChart.setOption(mapConfig, true);
    mapChart.on('click', (params) => {
      return;
      if (tempName === params.name) {
        tempName = '';
        this.initConfig();
        mapChart.setOption(mapConfig, true);
        this.$emit('filterData', '');
      } else {
        tempName = params.name;
        this.filterData(params.name);
      }
    });
    this.observe();
  },
  beforeDestroy() {
    if (observer) {
      mapChart.dispose();
      observer.unobserve(this.$refs.map);
    }
  },
}
</script>

<style lang="scss" scoped>
.map-container {
  width: 100%;
  flex: 1;
  margin-bottom: 20px;
  display: flex;
  flex-direction: column;

  .map-content {
    flex: 1;
    // background: rgba(67, 102, 155, 0.3);
    // border: 1px solid rgba(47, 91, 157, 0.8);
  }

  .map-style {
    width: 100%;
    height: 100%;
  }
}
</style>